@@ -30,6 +30,9 @@ class CloudControlClient:
     def get_all_tags(self, filters=None):
         return self.__get_all_available_of_type(list_tags, 'tag', filters)
 
+    def get_tags(self, event):
+        return self.http_client.get_with_filters(list_tags, event)
+
     def get_all_network_domains(self):
         return self.__get_all_available_of_type(list_network_domains, 'networkDomain')
 
